@@ -13,11 +13,17 @@ __all__ = (
 
 
 class BaseCredentialMixin(object):
-
     if settings.DASHBOARD_URL.endswith("/"):
         url = settings.DASHBOARD_URL
     else:
         url = settings.DASHBOARD_URL + '/'
+        header_param = 'Authorization'
+
+    if hasattr(settings, 'IS_BOX_APP') and settings.IS_BOX_APP:
+        url = f'{settings.DASHBOARD_URL}auth-new/me'
+    else:
+        url = f'{url}api/check-platform/'
+        header_param = 'executetoken'
 
     def get_user_info(
         self, request, **kwargs
@@ -32,8 +38,8 @@ class BaseCredentialMixin(object):
             )
         try:
             response = requests.get(
-                f"{self.url}api/check-platform/?platform_id={request.GET['platform_id']}",
-                headers={"executetoken": token},
+                f"{self.url}?platform_id={request.GET['platform_id']}",
+                headers={self.header_param: token},
             )
         except requests.ConnectionError:
             raise PermissionDenied(
@@ -62,21 +68,6 @@ class CredentialMixin(BaseCredentialMixin):
     check_credential = True
     with_smart_auth = True
 
-    # method for dashboard app
-    def get_check_dash_auth(self, request):
-        if 'HTTP_EXECUTETOKEN' not in request.META:
-            raise PermissionDenied(
-                {"status": "error", "message": "you don't have permission to access"}
-            )
-        auth_info = requests.post(
-            f"{self.url}api/check-auth/",
-            headers={"executetoken": request.META['HTTP_EXECUTETOKEN']},
-        ).json()
-        if "is_admin" not in auth_info:
-            raise PermissionDenied({"status": "error", "message": "Invalid dash user."})
-
-        return auth_info["is_admin"]
-
     def check_mongo_credential(self):
         mongo_credential = getattr(settings, 'MONGODANTIC_CREDENTIAL', False)
         return mongo_credential
