@@ -66,24 +66,31 @@ def get_smart_token(platform: str) -> str:
     :param platform: str (prod or dev)
     :return: str
     """
-    url = f'{DASHBOARD_URL}api/smart_tokens/?platform_id={platform}'
-    token = settings.EXECUTE_TOKEN
-    try:
-        r = requests.get(url, headers={"executetoken": token}).json()
-    except (requests.ConnectionError, json.JSONDecodeError):
-        return 'error'
-    return r['token']
+    if hasattr(settings, 'IS_BOX_APP') and settings.IS_BOX_APP:
+        return settings.AUTH_TOKEN
+    else:
+        url = f'{DASHBOARD_URL}api/smart_tokens/?platform_id={platform}'
+        token = settings.EXECUTE_TOKEN
+        try:
+            r = requests.get(url, headers={"executetoken": token}).json()
+        except (requests.ConnectionError, json.JSONDecodeError):
+            return 'error'
+        return r['token']
 
 
 def get_integration_info(
     platform: str, integration_id: int, token: Optional[str] = None
 ) -> dict:
-    if not token:
-        token = get_smart_token(platform)
-    config_url = f'{DASHBOARD_URL}api/get_config_url/?platform_id={platform}'
-    dash_response = requests.get(f'{config_url}').json()
-    headers = {"Authorization": token}
-    integration_url = f'{dash_response["config_url"]}{integration_id}/'
+    if hasattr(settings, 'IS_BOX_APP') and settings.IS_BOX_APP:
+        headers = {"Authorization": settings.AUTH_TOKEN}
+        integration_url = f'{DASHBOARD_URL}/integrations/{integration_id}'
+    else:
+        if not token:
+            token = get_smart_token(platform)
+        config_url = f'{DASHBOARD_URL}api/get_config_url/?platform_id={platform}'
+        dash_response = requests.get(f'{config_url}').json()
+        headers = {"Authorization": token}
+        integration_url = f'{dash_response["config_url"]}{integration_id}/'
     integration = requests.get(integration_url, headers=headers).json()
     return integration
 
@@ -126,7 +133,7 @@ def upload_to_s3(filename: str, folder: str = "stats/") -> dict:
     :return: dict
     """
     s3 = boto3.resource('s3')
-    GB = 1024 ** 3
+    GB = 1024**3
     config = TransferConfig(multipart_threshold=int(GB / 3))
     if filename.startswith('/tmp/'):
         s3_filename = filename[5:]
@@ -136,7 +143,7 @@ def upload_to_s3(filename: str, folder: str = "stats/") -> dict:
         folder = folder[1:]
     if not folder.endswith('/'):
         folder = f'{folder}/'
-    s3.meta.client.upload_file(
+    s3.meta.client.upload_file(  # type: ignore
         filename,
         BUCKET_NAME,
         f"{folder}{s3_filename}",
@@ -154,7 +161,7 @@ def check_file_exist(filename: str, folder: str = "stats/") -> bool:
     :return: bool
     """
     s3 = boto3.resource('s3')
-    bucket = s3.Bucket(BUCKET_NAME)
+    bucket = s3.Bucket(BUCKET_NAME)  # type: ignore
     if filename.startswith('/tmp/'):
         filename = filename[5:]
     if folder.startswith('/'):
@@ -391,7 +398,7 @@ def upload_to_s3_from_ram(
         if isinstance(content, StringIO)
         else content.getvalue()
     )
-    s3.meta.client.put_object(
+    s3.meta.client.put_object(  # type: ignore
         Bucket=BUCKET_NAME, Key=f'{folder}{s3_filename}', Body=body, ACL='public-read'
     )
     return {"status": "success", "s3_filename": s3_filename, "s3_folder": folder}
